=========
Tutorials
=========

Beginner
========

This document lists some beginner's tutorials. These tutorials are aimed at
people who are starting to learn how to use PyDy. These tutorials are in the
form of IPython notebooks.

Tutorials:

  - :ref:`Linear Mass-Spring-Damper with Gravity <mass-spring-damper>`
  - `Inverted pendulum model of a standing human`_

.. _`Inverted pendulum model of a standing human`: http://nbviewer.ipython.org/github/pydy/pydy-tutorial-human-standing/blob/online-read/notebooks/n00_python_intro.ipynb

Advanced
========

This document lists some advanced tutorials. These tutorials require
sufficiently good knowledge about mechanics concepts. These tutorials are in
the form of IPython notebooks.

Tutorials:

  - `N Pendulum example`_

.. _`N Pendulum example`: http://nbviewer.ipython.org/github/pydy/pydy/blob/master/examples/npendulum/n-pendulum-control.ipynb
